pub trait TypeLike<'c> {
Show 51 methods
// Required method
fn to_raw(&self) -> MlirType;
// Provided methods
fn context(&self) -> ContextRef<'c> { ... }
fn id(&self) -> TypeId<'c> { ... }
fn dialect(&self) -> Dialect<'c> { ... }
fn dump(&self) { ... }
fn is_any_quantized_type(&self) -> bool { ... }
fn is_bf16(&self) -> bool { ... }
fn is_calibrated_quantized_type(&self) -> bool { ... }
fn is_complex(&self) -> bool { ... }
fn is_f16(&self) -> bool { ... }
fn is_f32(&self) -> bool { ... }
fn is_f64(&self) -> bool { ... }
fn is_float(&self) -> bool { ... }
fn is_float8e4m3(&self) -> bool { ... }
fn is_float8e4m3_b_11_fnuz(&self) -> bool { ... }
fn is_float8e4m3fn(&self) -> bool { ... }
fn is_float8e4m3fnuz(&self) -> bool { ... }
fn is_float8e5m2(&self) -> bool { ... }
fn is_float8e5m2fnuz(&self) -> bool { ... }
fn is_function(&self) -> bool { ... }
fn is_gpu_async_token_type(&self) -> bool { ... }
fn is_index(&self) -> bool { ... }
fn is_integer(&self) -> bool { ... }
fn is_llvm_pointer_type(&self) -> bool { ... }
fn is_llvm_struct_type(&self) -> bool { ... }
fn is_mem_ref(&self) -> bool { ... }
fn is_none(&self) -> bool { ... }
fn is_nvgpu_tensor_map_descriptor_type(&self) -> bool { ... }
fn is_opaque(&self) -> bool { ... }
fn is_pdl_attribute_type(&self) -> bool { ... }
fn is_pdl_operation_type(&self) -> bool { ... }
fn is_pdl_range_type(&self) -> bool { ... }
fn is_pdl_type(&self) -> bool { ... }
fn is_pdl_type_type(&self) -> bool { ... }
fn is_pdl_value_type(&self) -> bool { ... }
fn is_quantized_type(&self) -> bool { ... }
fn is_ranked_tensor(&self) -> bool { ... }
fn is_shaped(&self) -> bool { ... }
fn is_tensor(&self) -> bool { ... }
fn is_tf32(&self) -> bool { ... }
fn is_transform_any_op_type(&self) -> bool { ... }
fn is_transform_any_param_type(&self) -> bool { ... }
fn is_transform_any_value_type(&self) -> bool { ... }
fn is_transform_operation_type(&self) -> bool { ... }
fn is_transform_param_type(&self) -> bool { ... }
fn is_tuple(&self) -> bool { ... }
fn is_uniform_quantized_per_axis_type(&self) -> bool { ... }
fn is_uniform_quantized_type(&self) -> bool { ... }
fn is_unranked_mem_ref(&self) -> bool { ... }
fn is_unranked_tensor(&self) -> bool { ... }
fn is_vector(&self) -> bool { ... }
}Expand description
Trait for type-like types.
Required Methods
Provided Methods
Sourcefn context(&self) -> ContextRef<'c>
fn context(&self) -> ContextRef<'c>
Returns a context.
Sourcefn is_any_quantized_type(&self) -> bool
fn is_any_quantized_type(&self) -> bool
Returns true if a type is any quantized type.
Sourcefn is_calibrated_quantized_type(&self) -> bool
fn is_calibrated_quantized_type(&self) -> bool
Returns true if a type is calibrated quantized type.
Sourcefn is_complex(&self) -> bool
fn is_complex(&self) -> bool
Returns true if a type is complex.
Sourcefn is_float8e4m3(&self) -> bool
fn is_float8e4m3(&self) -> bool
Returns true if a type is float8e4m3.
Sourcefn is_float8e4m3_b_11_fnuz(&self) -> bool
fn is_float8e4m3_b_11_fnuz(&self) -> bool
Returns true if a type is float8e4m3 b 11 fnuz.
Sourcefn is_float8e4m3fn(&self) -> bool
fn is_float8e4m3fn(&self) -> bool
Returns true if a type is float8e4m3fn.
Sourcefn is_float8e4m3fnuz(&self) -> bool
fn is_float8e4m3fnuz(&self) -> bool
Returns true if a type is float8e4m3fnuz.
Sourcefn is_float8e5m2(&self) -> bool
fn is_float8e5m2(&self) -> bool
Returns true if a type is float8e5m2.
Sourcefn is_float8e5m2fnuz(&self) -> bool
fn is_float8e5m2fnuz(&self) -> bool
Returns true if a type is float8e5m2fnuz.
Sourcefn is_function(&self) -> bool
fn is_function(&self) -> bool
Returns true if a type is function.
Sourcefn is_gpu_async_token_type(&self) -> bool
fn is_gpu_async_token_type(&self) -> bool
Returns true if a type is gpu async token type.
Sourcefn is_integer(&self) -> bool
fn is_integer(&self) -> bool
Returns true if a type is integer.
Sourcefn is_llvm_pointer_type(&self) -> bool
fn is_llvm_pointer_type(&self) -> bool
Returns true if a type is llvm pointer type.
Sourcefn is_llvm_struct_type(&self) -> bool
fn is_llvm_struct_type(&self) -> bool
Returns true if a type is llvm struct type.
Sourcefn is_mem_ref(&self) -> bool
fn is_mem_ref(&self) -> bool
Returns true if a type is mem ref.
Sourcefn is_nvgpu_tensor_map_descriptor_type(&self) -> bool
fn is_nvgpu_tensor_map_descriptor_type(&self) -> bool
Returns true if a type is nvgpu tensor map descriptor type.
Sourcefn is_pdl_attribute_type(&self) -> bool
fn is_pdl_attribute_type(&self) -> bool
Returns true if a type is pdl attribute type.
Sourcefn is_pdl_operation_type(&self) -> bool
fn is_pdl_operation_type(&self) -> bool
Returns true if a type is pdl operation type.
Sourcefn is_pdl_range_type(&self) -> bool
fn is_pdl_range_type(&self) -> bool
Returns true if a type is pdl range type.
Sourcefn is_pdl_type(&self) -> bool
fn is_pdl_type(&self) -> bool
Returns true if a type is pdl type.
Sourcefn is_pdl_type_type(&self) -> bool
fn is_pdl_type_type(&self) -> bool
Returns true if a type is pdl type type.
Sourcefn is_pdl_value_type(&self) -> bool
fn is_pdl_value_type(&self) -> bool
Returns true if a type is pdl value type.
Sourcefn is_quantized_type(&self) -> bool
fn is_quantized_type(&self) -> bool
Returns true if a type is quantized type.
Sourcefn is_ranked_tensor(&self) -> bool
fn is_ranked_tensor(&self) -> bool
Returns true if a type is ranked tensor.
Sourcefn is_transform_any_op_type(&self) -> bool
fn is_transform_any_op_type(&self) -> bool
Returns true if a type is transform any op type.
Sourcefn is_transform_any_param_type(&self) -> bool
fn is_transform_any_param_type(&self) -> bool
Returns true if a type is transform any param type.
Sourcefn is_transform_any_value_type(&self) -> bool
fn is_transform_any_value_type(&self) -> bool
Returns true if a type is transform any value type.
Sourcefn is_transform_operation_type(&self) -> bool
fn is_transform_operation_type(&self) -> bool
Returns true if a type is transform operation type.
Sourcefn is_transform_param_type(&self) -> bool
fn is_transform_param_type(&self) -> bool
Returns true if a type is transform param type.
Sourcefn is_uniform_quantized_per_axis_type(&self) -> bool
fn is_uniform_quantized_per_axis_type(&self) -> bool
Returns true if a type is uniform quantized per axis type.
Sourcefn is_uniform_quantized_type(&self) -> bool
fn is_uniform_quantized_type(&self) -> bool
Returns true if a type is uniform quantized type.
Sourcefn is_unranked_mem_ref(&self) -> bool
fn is_unranked_mem_ref(&self) -> bool
Returns true if a type is unranked mem ref.
Sourcefn is_unranked_tensor(&self) -> bool
fn is_unranked_tensor(&self) -> bool
Returns true if a type is unranked tensor.